@@ -1,3 +1,5 @@
+# SPDX-FileCopyrightText: 2025 QinHan
+# SPDX-License-Identifier: MPL-2.0
 import asyncio
 from dataclasses import dataclass
 from pathlib import Path
@@ -6,12 +8,14 @@ from typing import Self, Tuple, Type
 from docutranslate.cacher import md_based_convert_cacher
 from docutranslate.exporter.base import ExporterConfig
 from docutranslate.global_values.conditional_import import DOCLING_EXIST
+from docutranslate.glossary.glossary import Glossary
 from docutranslate.ir.document import Document
 from docutranslate.ir.markdown_document import MarkdownDocument
+from docutranslate.utils.markdown_utils import embed_inline_image_from_zip
 
 if DOCLING_EXIST:
     from docutranslate.converter.x2md.converter_docling import ConverterDoclingConfig, ConverterDocling
-from docutranslate.converter.x2md.converter_identity import ConverterIdentity
+from docutranslate.converter.converter_identity import ConverterIdentity
 from docutranslate.converter.x2md.converter_mineru import ConverterMineruConfig, ConverterMineru
 from docutranslate.converter.x2md.base import X2MarkdownConverterConfig, X2MarkdownConverter
 from docutranslate.exporter.md.md2html_exporter import MD2HTMLExporterConfig, MD2HTMLExporter
@@ -35,7 +39,8 @@ class MarkdownBasedWorkflow(Workflow[MarkdownBasedWorkflowConfig, Document, Mark
                             HTMLExportable[MD2HTMLExporterConfig],
                             MDFormatsExportable[ExporterConfig]):
     _converter_factory: dict[
-        ConvertEngineType, Tuple[Type[X2MarkdownConverter], Type[X2MarkdownConverterConfig]] | None] = {
+        ConvertEngineType, Tuple[Type[X2MarkdownConverter | ConverterIdentity], Type[
+            X2MarkdownConverterConfig]] | None] = {
         "mineru": (ConverterMineru, ConverterMineruConfig),
         "identity": (ConverterIdentity, None)
     }
@@ -55,10 +60,13 @@ class MarkdownBasedWorkflow(Workflow[MarkdownBasedWorkflowConfig, Document, Mark
         if self.document_original is None:
             raise RuntimeError("File has not been read yet. Call read_path or read_bytes first.")
 
+        if self.document_original.suffix.lower() == ".zip":
+            self.document_original = self._get_md_from_zip(self.document_original)
         # 获取缓存的解析后文件
         document_cached = md_based_convert_cacher.get_cached_result(self.document_original, convert_engin,
                                                                     convert_config)
         if document_cached:
+            self.attachment.add_document("md_cached", document_cached.copy())
             return document_cached
 
         # 未缓存则解析文件
@@ -70,13 +78,24 @@ class MarkdownBasedWorkflow(Workflow[MarkdownBasedWorkflowConfig, Document, Mark
             converter = converter_class(convert_config)
         else:
             raise ValueError(f"不存在{convert_engin}解析引擎")
-        document_md = converter.convert(self.document_original)
-        # 获取缓存解析后文件
-        md_based_convert_cacher.cache_result(document_md, self.document_original, convert_engin, convert_config)
+        document_md: Document = converter.convert(self.document_original)
+        if hasattr(converter, "attachments"):
+            for attachment in converter.attachments:
+                self.attachment.add_attachment(attachment)
+        # 缓存解析后文件
+        md_based_convert_cacher.cache_result(document_md.copy(), self.document_original, convert_engin, convert_config)
+
         return document_md
 
+    def _get_md_from_zip(self, document: Document) -> Document:
+        assert document.suffix.lower() == ".zip"
+        self.logger.info("传入zip文件，正在自动组合markdown文本与图片")
+        content_byte = embed_inline_image_from_zip(document.content).encode()
+        return document.from_bytes(content_byte, suffix=".md", stem=document.stem)
+
     def _pre_translate(self, document: Document):
-        convert_engine: ConvertEngineType = "identity" if document.suffix == ".md" else self.convert_engine
+        convert_engine: ConvertEngineType = "identity" if document.suffix.lower() in [".md", ".markdown",
+                                                                                      ".zip"] else self.convert_engine
         convert_config = self.config.converter_config
         translator_config = self.config.translator_config
         translator = MDTranslator(translator_config)
@@ -86,6 +105,8 @@ class MarkdownBasedWorkflow(Workflow[MarkdownBasedWorkflowConfig, Document, Mark
         convert_engine, convert_config, translator_config, translator = self._pre_translate(self.document_original)
         document_md = self._get_document_md(convert_engine, convert_config)
         translator.translate(document_md)
+        if translator.glossary_dict_gen:
+            self.attachment.add_document("glossary", Glossary.glossary_dict2csv(translator.glossary_dict_gen))
         self.document_translated = document_md
         return self
 
@@ -93,6 +114,8 @@ class MarkdownBasedWorkflow(Workflow[MarkdownBasedWorkflowConfig, Document, Mark
         convert_engine, convert_config, translator_config, translator = self._pre_translate(self.document_original)
         document_md = await asyncio.to_thread(self._get_document_md, convert_engine, convert_config)
         await translator.translate_async(document_md)
+        if translator.glossary_dict_gen:
+            self.attachment.add_document("glossary", Glossary.glossary_dict2csv(translator.glossary_dict_gen))
         self.document_translated = document_md
         return self
 
